@@ -1,4 +1,5 @@
 import os
+import sys
 from typing import Any
 
 import docker  # type: ignore
@@ -8,10 +9,10 @@ from treebeard.conf import treebeard_env
 from treebeard.util import fatal_exit
 
 
-def run(project_id: str, notebook_id: str, run_id: str, image_name: str):
+def run(project_id: str, notebook_id: str, run_id: str, image_name: str) -> int:
     client: Any = docker.from_env()  # type: ignore
     client.images.pull(image_name)
-    run_image(project_id, notebook_id, run_id, image_name)
+    return run_image(project_id, notebook_id, run_id, image_name)
 
 
 if __name__ == "__main__":
@@ -24,9 +25,11 @@ if __name__ == "__main__":
     image_name = os.getenv(image_name_key)
     if not image_name:
         fatal_exit(f"No image supplied under {image_name_key}")
-    run(
-        treebeard_env.project_id,
-        treebeard_env.notebook_id,
-        treebeard_env.run_id,
-        image_name,
+    sys.exit(
+        run(
+            treebeard_env.project_id,
+            treebeard_env.notebook_id,
+            treebeard_env.run_id,
+            image_name,
+        )
     )
