@@ -11,6 +11,7 @@ from sentry_sdk import capture_exception  # type: ignore
 
 from treebeard.conf import run_path, treebeard_config, treebeard_env
 from treebeard.importchecker.imports import check_imports
+from treebeard.logs.helpers import clean_log_file
 from treebeard.runtime.helper import log, upload_artifact
 
 bucket_name = "treebeard-notebook-outputs"
@@ -51,6 +52,11 @@ def save_artifacts(notebook_statuses: Dict[str, str]):
                     upload_path = f"{run_path}/{full_name}"
                     executor.submit(upload_artifact, full_name, upload_path, None)
 
+        if os.path.exists("treebeard.log"):
+            executor.submit(
+                upload_artifact, "treebeard.log", f"{run_path}/treebeard.log", None
+            )
+
 
 def run_notebook(notebook_path: str) -> str:
     try:
@@ -116,6 +122,8 @@ def start():
     if not treebeard_env.project_id:
         raise Exception("No project ID at buildtime")
 
+    clean_log_file()
+
     notebook_statuses = run(
         treebeard_env.project_id, treebeard_env.notebook_id, treebeard_env.run_id
     )
@@ -144,8 +152,10 @@ def start():
                         )
                         sys.exit(0)
         except Exception as ex:
+            click.echo(f"Import checker encountered and error...")
             capture_exception(ex)
         sys.exit(1)
+    sys.exit(0)
 
 
 if __name__ == "__main__":
